/*
    uhttp_client.h - Minimalistic HTTP client library.
    Copyright (C) 2008  Avelino Herrera Morales

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef  __UHTTP_CLIENT_H__
#define  __UHTTP_CLIENT_H__

#ifdef __cplusplus
extern "C" {
#endif

#define  UHTTP_STATUS_DISCONNECTED  0
#define  UHTTP_STATUS_IDLE          1
#define  UHTTP_STATUS_CONNECTING    2
#define  UHTTP_STATUS_SENDING       3
#define  UHTTP_STATUS_RECEIVING     4
#define  UHTTP_STATUS_ERROR         5

extern int uhttp_status;

#define  UHTTP_OK                          0
#define  UHTTP_ERROR_ALREADY_CONNECTED     1
#define  UHTTP_ERROR_PARSE_URL             2
#define  UHTTP_ERROR_NOT_IDLE              3
#define  UHTTP_ERROR_UNABLE_TO_RESOLVE     4
#define  UHTTP_ERROR_SOCKET                5
#define  UHTTP_ERROR_UNABLE_TO_CONNECT     6
#define  UHTTP_ERROR_UNABLE_TO_SEND        7
#define  UHTTP_ERROR_UNABLE_TO_RECEIVE     8
#define  UHTTP_TRY_AGAIN                   9
#define  UHTTP_ERROR_NO_MEM                10
#define  UHTTP_ERROR_UNABLE_TO_REUSE_ADDR  11

extern int uhttp_errno;
extern const char *uhttp_errlist[];
extern void (*uhttp_sending_callback)(int);
extern void (*uhttp_receiving_callback)(int);
extern unsigned long long uhttp_send_transfer_speed;
extern unsigned long long uhttp_recv_transfer_speed;

int uhttp_connect(char *url);
void uhttp_set_proxy_configuration(char *user, char *passwd, char *host, int port);
void uhttp_set_proxy_configuration_from_environment(void);
void uhttp_enable_transfer_speed_measurement(int enable);
int uhttp_get_proxy_configuration(char *user, char *passwd, char *host, int *port);
int uhttp_get_socket_fd(void);
int uhttp_prepare_request(unsigned char *to_send, int to_send_size, unsigned char **to_receive, int *to_receive_size);
int uhttp_prepare_filed_request(unsigned char *to_send, int to_send_size, int fd);
int uhttp_prepare_filep_request(unsigned char *to_send, int to_send_size, FILE *fp);
int uhttp_poll_request(long sec, long usec);
void uhttp_disconnect(void);

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif
