/*
    uwget.c - Minimalistic HTTP client library example.
    Copyright (C) 2008  Avelino Herrera Morales

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <errno.h>
#include "uhttp_client.h"


char proxy_user[80];
char proxy_passwd[80];
char proxy_host[80];
char proxy_port_str[10];
int proxy_port;
int mark_counter = 0;

#define  MARK_SIZE  1024

void my_receiving_callback(int readed) {
	mark_counter += readed;
	if (mark_counter >= MARK_SIZE)
		mark_counter -= MARK_SIZE;
}


int main(int argc, char **argv) {
	int fd;

	if (argc != 3) {
		printf("usage: %s url local_file\n", argv[0]);
		return 1;
	}

	uhttp_set_proxy_configuration_from_environment();
	uhttp_enable_transfer_speed_measurement(1);
	// connect
	mark_counter = 0;
	uhttp_receiving_callback = my_receiving_callback;
	uhttp_connect(argv[1]);
	if ((fd = open(argv[2], O_WRONLY | O_CREAT | O_TRUNC, 0644)) < 0) {
		printf("open: %s\n", strerror(errno));
		return 1;
	}
	uhttp_prepare_filed_request(NULL, 0, fd);
	while (uhttp_poll_request(0, 0) != 0) {
		if ((uhttp_errno != UHTTP_TRY_AGAIN) && (uhttp_errno != UHTTP_ERROR_UNABLE_TO_RECEIVE)) {
			printf("Error: %s\n", uhttp_errlist[uhttp_errno]);
			return 1;
		}
	}
	close(fd);
	printf("upload rate: %llu kbytes/seg\n", uhttp_send_transfer_speed);
	printf("download rate: %llu kbytes/seg\n", uhttp_recv_transfer_speed);

	return 0;
}
